Contributing
============

.. _contributing:

To contribute to HydroMT and the wflow plugin, please follow the 
`HydroMT contribution guidelines <https://hydromt.readthedocs.io/en/latest/contributing.html>`_.